@@ -13,7 +13,7 @@ from pstats import Stats
 from jinja2 import Template
 
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 __licence__ = 'New BSD License'
 __author__ = 'Hideo Hattori <syobosyobo@gmail.com>'
 
@@ -290,18 +290,18 @@ def check_hotshot(dump):
     return signature in dump
 
 
-def mapping_table(target, all):
+def mapping_table(target, nall):
     levelmap = {0: '#ccffcc',   ## yellow green (light)
                 1: '#66ff99',   ## yellow green
                 2: '#ffcc33',   ## orange
                 3: '#ff6666',   ## pink
                 4: '#ff3333',   ## red
                 }
-    level_list = [all*0.01, all*0.03, all*0.08, all*0.12, all*0.20]
-    for level in range(len(level_list)):
-        if target < level_list[level]:
-            break
-    return levelmap[level]
+    levels = [nall*0.01, nall*0.03, nall*0.08, nall*0.12, nall*0.20]
+    for level in range(len(levels)):
+        if target < levels[level]:
+            return levelmap[level]
+    return levelmap[len(levelmap)-1]
 
 
 class Converter:
@@ -330,7 +330,7 @@ class Converter:
         self.outputtype = 'html'
         self.functions_number = 20
 
-    def _printhtml_onesource(self, filename, profs):
+    def _printhtml_source(self, filename, profs):
         """printing one file profile line. return value is html render
         strings.
         """
@@ -362,7 +362,7 @@ class Converter:
                                     profdata=result,
                                     codec=codec)
 
-    def _print_onesource(self, filename, profs):
+    def _print_source(self, filename, profs):
         """printing one file profile line. return value is text strings.
         """
         num = 0
@@ -384,51 +384,40 @@ class Converter:
                 result.append("         |          | %s" % (line))
         return ''.join(result)
 
-    def _print_source(self, profs):
-        """wrapper of _print_onesource() and _printhtml_onesource() method.
+    def _print_sources(self, profs):
+        """wrapper of _print_source() and _printhtml_source() method.
         """
-        source_list = []
+        sources = []
         info = {}
-        filename = None
         filecnt = 0
-        for prof in profs:
+        for i, prof in enumerate(profs):
+            print prof
             filename = prof[0]
-            if not source_list.count(filename):
+            if (not sources.count(filename)) or (len(profs) == (i+1)):
                 if info != {}:
-                    filecnt += 1
                     if self.outputtype == 'html':
-                        output_filename = "%s/%s.html" % (self.output_dir,
-                                 os.path.basename(source_list[filecnt-1]))
-                        outputfile = open(output_filename, 'w')
+                        out_filename = "%s/%s.html" % (self.output_dir,
+                                       sources[filecnt].replace('/', '_'))
+                        outputfile = open(out_filename, 'w')
                         print >> outputfile, XHTML_HEADER_TEMPLATE
-                        print >> outputfile, self._printhtml_onesource(
-                                                  source_list[filecnt-1],
-                                                  info)
+                        print >> outputfile, self._printhtml_source(
+                                                  sources[filecnt], info)
                         print >> outputfile, XHTML_FOOTER_TEMPLATE
                         outputfile.close()
                     else:
-                        print self._print_onesource(source_list[filecnt-1],
-                                                    info)
+                        print self._print_source(sources[filecnt], info)
+                    filecnt += 1
                 info = {}
-                source_list.append(filename)
+                sources.append(filename)
             info[prof[1]] = {'sec':prof[2], 'cnt':prof[3]}
-        if self.outputtype == 'html':
-            output_htmlfile = "%s.html" % (os.path.basename(
-                                           source_list[filecnt-1]))
-            outputfile = open("%s/%s" % (self.output_dir,
-                                         output_htmlfile), 'w')
-            print >> outputfile, XHTML_HEADER_TEMPLATE
-            print >> outputfile, self._printhtml_onesource(filename, info)
-            print >> outputfile, XHTML_FOOTER_TEMPLATE
-            outputfile.close()
-        else:
-            print self._print_onesource(filename, info)
 
     def _analyze_profline(self):
         """analyzed to hotshot linetimings data.
         """
         profset = dict()
         for i in self.profline:
+            if i[0] == 0 or i[0] == 1:  # WHAT_ENTER or WHAT_EXIT
+                continue
             if i[1] not in profset:
                 profset[i[1]] = [float(int(i[2])/1000000.), i[2]]
             else:
@@ -442,12 +431,11 @@ class Converter:
         """analyzed to not linetimings profile data.
         """
         self.prof.sort_stats('time', 'calls')
-        null = open('/dev/null', 'w')   # darty hack (order output block)
-        self.prof.stream = null
+        self.prof.stream = open(os.devnull, 'w')    ## darty hack
         backstream = self.prof.stream
         tmp, funclist = self.prof.get_print_list(())
         self.prof.stream = backstream
-        null.close()
+        self.prof.stream.close()
         datalist = list()
         cnt = 0
         for func in funclist:
@@ -474,7 +462,7 @@ class Converter:
             totclevel = mapping_table(float(totpercall), self.prof.total_tt)
             cumtlevel = mapping_table(1, 1000)
             cumclevel = mapping_table(1, 1000)
-            linelink = "%s.html" % os.path.basename(func[0])
+            linelink = "%s.html" % func[0].replace('/', '_')
             data = {
                 'func': func,
                 'linelink': linelink,
@@ -501,8 +489,8 @@ class Converter:
         """hook rawtext print
         """
         if self.proftype == 'line':
-            proflist = self._analyze_profline()
-            self._print_source(proflist)
+            profs = self._analyze_profline()
+            self._print_sources(profs)
         else:
             self.prof.sort_stats('time', 'calls')
             self.prof.print_stats()
@@ -524,8 +512,8 @@ class Converter:
                                                 thisname=self.output_htmlfile,
                                                 proftype=self.proftype)
         if self.proftype:
-            profinfo = self._analyze_profline()
-            self._print_source(profinfo)
+            profs = self._analyze_profline()
+            self._print_sources(profs)
         print >> self.outfile, XHTML_FOOTER_TEMPLATE
         self.outfile.close()
 
@@ -542,8 +530,8 @@ class Converter:
 def main():
     """execute a script"""
     from optparse import OptionParser
-    parser = OptionParser(version="%s version:%s" % (__file__, __version__),
-                          usage="Usage: pyprof2html [options] arg1")
+    parser = OptionParser(version="pyprof2html %s" % (__version__),
+                          usage="Usage: pyprof2html [options] PROFILE_DATA")
     parser.add_option('-r', '--raw', action='store_true',
                       help='raw print mode')
     parser.add_option('-x', '--xhtml', action='store_true',
@@ -554,7 +542,7 @@ def main():
                       default=20, help='print to N funcs.(default 20)')
     parser.add_option('-o', '--output-dir', dest='output_dir', default='html',
                       help='output HTML under the this directory.' \
-                           '(default: html/')
+                           '(default: html)')
     opts, args = parser.parse_args()
     if not len(args):
         parser.parse_args(['-h'])
@@ -573,6 +561,7 @@ def main():
     p2h.printout(outmode)
     if outmode == 'html':
         p2h = Converter(args[0])
+        p2h.output_dir = opts.output_dir
         p2h.functions_number = 99999
         p2h.output_htmlfile = 'index-all.html'
         p2h.printout(outmode)
