@@ -66,57 +66,57 @@ class ColorMappingTest(pikzie.TestCase):
 
     def test_mapping_v1(self):
         ret = p2h.mapping_table(1, 1000)
-        self.assert_equal(ret, 0)
+        self.assert_equal(ret, '#ccffcc')
 
     def test_mapping_v2(self):
         ret = p2h.mapping_table(29, 1000)
-        self.assert_equal(ret, 1)
+        self.assert_equal(ret, '#66ff99')
 
     def test_mapping_v3(self):
         ret = p2h.mapping_table(79, 1000)
-        self.assert_equal(ret, 2)
+        self.assert_equal(ret, '#ffcc33')
 
     def test_mapping_v4(self):
         ret = p2h.mapping_table(119, 1000)
-        self.assert_equal(ret, 3)
+        self.assert_equal(ret, '#ff6666')
 
     def test_mapping_v5(self):
         ret = p2h.mapping_table(199, 1000)
-        self.assert_equal(ret, 4)
+        self.assert_equal(ret, '#ff3333')
 
     def test_mapping_min(self):
         ret = p2h.mapping_table(0, 100)
-        self.assert_equal(ret, 0)
+        self.assert_equal(ret, '#ccffcc')
 
     def test_mapping_max(self):
         ret = p2h.mapping_table(100, 100)
-        self.assert_equal(ret, 4)
+        self.assert_equal(ret, '#ff3333')
 
     def test_mapping_v1_float(self):
         ret = p2h.mapping_table(1., 1000.)
-        self.assert_equal(ret, 0)
+        self.assert_equal(ret, '#ccffcc')
 
     def test_mapping_v2_float(self):
         ret = p2h.mapping_table(10., 1000.)
-        self.assert_equal(ret, 1)
+        self.assert_equal(ret, '#66ff99')
 
     def test_mapping_v3_float(self):
         ret = p2h.mapping_table(79., 1000.)
-        self.assert_equal(ret, 2)
+        self.assert_equal(ret, '#ffcc33')
 
     def test_mapping_v4_float(self):
         ret = p2h.mapping_table(119., 1000.)
-        self.assert_equal(ret, 3)
+        self.assert_equal(ret, '#ff6666')
 
     def test_mapping_v5_float(self):
         ret = p2h.mapping_table(199., 1000.)
-        self.assert_equal(ret, 4)
+        self.assert_equal(ret, '#ff3333')
 
     def test_mapping_min_float(self):
         ret = p2h.mapping_table(0.0, 1000.0)
-        self.assert_equal(ret, 0)
+        self.assert_equal(ret, '#ccffcc')
 
     def test_mapping_max_float(self):
         ret = p2h.mapping_table(100., 100.)
-        self.assert_equal(ret, 4)
+        self.assert_equal(ret, '#ff3333')
 
